<?php
/**
 * Photo Fusion Pro Blog Customizer options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


// Add blog enable section
$wp_customize->add_section( 'photo_fusion_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','photo-fusion-pro' ),
	'description'       => esc_html__( 'Blog section options.', 'photo-fusion-pro' ),
	'panel'             => 'photo_fusion_pro_sections_panel'
) );

// Add blog enable setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_enable]', array(
	'default'           => $options['blog_enable'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[blog_enable]', array(
	'label'             => esc_html__( 'Enable on', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_blog_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_enable_disable_options()
) );

// Add blog content type setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_content_type]', array(
	'default'           => $options['blog_content_type'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[blog_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_blog_section',
	'type'            => 'select',
	'active_callback' => 'photo_fusion_pro_is_blog_section_active',
	'choices'         => photo_fusion_pro_blog_content_type()
) );

// Add blog title setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_title]', array(
	'default'           => $options['blog_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[blog_title]', array(
	'label'           => esc_html__( 'Title', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_blog_section',
	'type'            => 'text',
	'active_callback' => 'photo_fusion_pro_is_blog_content_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'photo_fusion_pro_theme_options[blog_title]', array(
		'selector'            => '#blog h2.entry-title',
		'render_callback'     => 'photo_fusion_pro_customize_partial_blog_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add blog description setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_description]', array(
	'default'           => $options['blog_description'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[blog_description]', array(
	'label'           => esc_html__( 'Description', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_blog_section',
	'type'            => 'textarea',
	'active_callback' => 'photo_fusion_pro_is_blog_content_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'photo_fusion_pro_theme_options[blog_description]', array(
		'selector'            => '#blog span.sub-title',
		'render_callback'     => 'photo_fusion_pro_customize_partial_blog_description',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add blog number setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_count]', array(
	'default'           => $options['blog_count'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range',
	'validate_callback' => 'photo_fusion_pro_validate_no_of_blog'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[blog_count]', array(
	'label'           => esc_html__( 'Number of posts.', 'photo-fusion-pro' ),
	'description'     => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_blog_section',
	'type'            => 'number',
	'active_callback' => 'photo_fusion_pro_is_blog_content_demo_inactive',
	'input_attrs'     => array(
		'max' => 6,
		'min' => 1
	)
) );

/**
 * Content type: Catgory
*/
// Show category type setting and control
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new photo_fusion_pro_Dropdown_Taxonomies_Control( $wp_customize, 'photo_fusion_pro_theme_options[blog_content_category]', array(
	'label'           => esc_html__( 'Category', 'photo-fusion-pro' ),
	'description'     => esc_html__( 'Select the category of posts to be shown.', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_blog_section',
	'active_callback' => 'photo_fusion_pro_is_blog_content_cat_active',
) ) );

/**
 * Content type: Post
*/
// Show post type setting and control
for ($i=1; $i <= $options['blog_count']; $i++) {
	# code...
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[blog_content_post_'.$i.']', array(
		'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[blog_content_post_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Post #%s', 'photo-fusion-pro' ), $i ),
		'description'     => esc_html__( 'Enter the Post ID here.', 'photo-fusion-pro' ),
		'section'         => 'photo_fusion_pro_blog_section',
		'active_callback' => 'photo_fusion_pro_is_blog_content_post_active',
		'type'				=> 'number',
		'input_attrs'     => array(
			'min'	=> 0
			)
	) );
}