<?php
/**
 * Slider Customizer options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


// Add slider enable section
$wp_customize->add_section( 'photo_fusion_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','photo-fusion-pro' ),
	'description'       => esc_html__( 'Slider section options.', 'photo-fusion-pro' ),
	'panel'             => 'photo_fusion_pro_sections_panel'
) );

// Add slider enable setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_enable]', array(
	'default'           => $options['slider_enable'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_enable]', array(
	'label'             => esc_html__( 'Enable on', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_slider_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_enable_disable_options()
) );

// Add slider effects setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_effect]', array(
	'default'           => $options['slider_content_effect'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_content_effect]', array(
	'label'           => esc_html__( 'Transition Effects', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'select',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
	'choices'         => photo_fusion_pro_slider_effect(),
) );

// Add enable slider captions setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[enable_slider_captions]', array(
	'default'           => $options['enable_slider_captions'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[enable_slider_captions]', array(
	'label'           => esc_html__( 'Enable slider captions', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
) );

// Add enable arrow controls setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[enable_arrow_controls]', array(
	'default'           => $options['enable_arrow_controls'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[enable_arrow_controls]', array(
	'label'           => esc_html__( 'Enable arrow controls', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[enable_slider_pager]', array(
	'default'           => $options['enable_slider_pager'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[enable_slider_pager]', array(
	'label'           => esc_html__( 'Enable pager controls', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[enable_slider_control_at_bottom]', array(
	'default'           => $options['enable_slider_control_at_bottom'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[enable_slider_control_at_bottom]', array(
	'label'           => esc_html__( 'Enable control at bottom', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[enable_slider_excerpt]', array(
	'default'           => $options['enable_slider_excerpt'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[enable_slider_excerpt]', array(
	'label'           => esc_html__( 'Enable Slider Excerpt', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_button_text]', array(
	'default'           => $options['slider_button_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_button_text]', array(
	'label'           => esc_html__( 'Button Label', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'text',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
) );

// Add slider content type setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_type]', array(
	'default'           => $options['slider_content_type'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'photo-fusion-pro' ),
	'description'     => esc_html__( 'Recommended slider image size is 1350x760 px', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'select',
	'active_callback' => 'photo_fusion_pro_is_slider_active',
	'choices'         => photo_fusion_pro_content_type()
) );

// Add slider number setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_page_count]', array(
	'default'           => $options['slider_content_page_count'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range',
	'validate_callback' => 'photo_fusion_pro_validate_no_of_slider',
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_content_page_count]', array(
	'label'           => esc_html__( 'Number of slides', 'photo-fusion-pro' ),
	'description'     => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_slider_section',
	'type'            => 'number',
	'active_callback' => 'photo_fusion_pro_is_slider_content_type_active',
	'input_attrs'     => array(
		'max' => 5,
		'min' => 1
	)
) );

/**
 * Page Content Type
 */
for ($i=1; $i <= $options['slider_content_page_count']; $i++) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_page_'.$i.']', array(
		'sanitize_callback' => 'photo_fusion_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_content_page_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Page Slider #%s', 'photo-fusion-pro' ), $i ),
		'section'         => 'photo_fusion_pro_slider_section',
		'active_callback' => 'photo_fusion_pro_is_slider_page_content_active',
		'type'				=> 'dropdown-pages'
	) );

	// Slider page hr setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_page_hr'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new photo_fusion_pro_Customize_Horizontal_Line( $wp_customize, 'photo_fusion_pro_theme_options[slider_content_page_hr'.$i.']',
		array(
			'section'         => 'photo_fusion_pro_slider_section',
			'active_callback' => 'photo_fusion_pro_is_slider_page_content_active',
			'type'				=> 'hr'
	) ) );
}

/*
* Post Content Type
 */
for ($i=1; $i <= $options['slider_content_page_count']; $i++) {
	// Show post type setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_post_'.$i.']', array(
		'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[slider_content_post_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Post Slider #%s', 'photo-fusion-pro' ), $i ),
		'description'           => esc_html__( 'Enter the Post ID here.', 'photo-fusion-pro' ),
		'section'         => 'photo_fusion_pro_slider_section',
		'active_callback' => 'photo_fusion_pro_is_slider_post_content_active',
		'type'				=> 'number',
		'input_attrs'     => array(
			'min'	=> 0
			)
	) );

	// Slider post hr setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[slider_content_post_hr'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new photo_fusion_pro_Customize_Horizontal_Line( $wp_customize, 'photo_fusion_pro_theme_options[slider_content_post_hr'.$i.']',
		array(
			'section'         => 'photo_fusion_pro_slider_section',
			'active_callback' => 'photo_fusion_pro_is_slider_post_content_active',
			'type'				=> 'hr'
	) ) );
}

/*
* Category Content Type
*/
// Add  dropdown category setting and control.
$wp_customize->add_setting(  'photo_fusion_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new photo_fusion_pro_Dropdown_Taxonomies_Control( $wp_customize,'photo_fusion_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Dropdown Category Control', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'photo_fusion_pro_content_category_active'
) ) );