<?php
/**
 * Adds a meta box to the post editing screen
 */
function photo_fusion_pro_custom_meta() {
    $post_types = array( 'post', 'page', 'jetpack-testimonial' );
    add_meta_box( 'photo_fusion_pro_meta', esc_html__( 'Sidebar Layout', 'photo-fusion-pro' ), 'photo_fusion_pro_sidebar_position_callback', $post_types );
}
add_action( 'add_meta_boxes', 'photo_fusion_pro_custom_meta' );


/**
 * Outputs the content of the sidebar position
 */
function photo_fusion_pro_sidebar_position_callback( $post ) {
    wp_nonce_field( basename( __FILE__ ), 'photo_fusion_pro_nonce' );
    $stored_sidebar_position = get_post_meta( $post->ID, 'photo-fusion-pro-sidebar-position', true );

    $sidebar_positions       = photo_fusion_pro_sidebar_position();
    ?>

    <p>
     <label for="photo-fusion-pro-sidebar-position" class="photo-fusion-pro-row-title"><?php esc_html_e( 'Sidebar Position', 'photo-fusion-pro' )?></label>
     <select name="photo-fusion-pro-sidebar-position" id="photo-fusion-pro-sidebar-position">
      <option value=""><?php esc_html_e( 'Default ( to customizer option )', 'photo-fusion-pro' ); ?></option>

        <?php foreach ( $sidebar_positions as $sidebar_position => $value ) { ?>
         <option value="<?php echo esc_attr( $sidebar_position );?>" <?php if ( isset ( $stored_sidebar_position ) ) selected( $stored_sidebar_position, $sidebar_position ); ?>><?php echo esc_html( $value ); ?></option>
        <?php } ?>
     </select>
    </p>
    <?php
}


/**
 * Saves the sidebar position input
 */
function photo_fusion_pro_meta_save( $post_id ) {

    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'photo_fusion_pro_nonce' ] ) && wp_verify_nonce( sanitize_key( $_POST[ 'photo_fusion_pro_nonce' ] ), basename( __FILE__ ) ) ) ? 'true' : 'false';

    // Exits script depending on save status
    if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
        return;
    }

    // Checks for input and sanitizes/saves if needed
    if( isset( $_POST[ 'photo-fusion-pro-sidebar-position' ] ) ) {
        update_post_meta( $post_id, 'photo-fusion-pro-sidebar-position', sanitize_text_field( $_POST[ 'photo-fusion-pro-sidebar-position' ] ) );
    }

}
add_action( 'save_post', 'photo_fusion_pro_meta_save' );